//
//  BidiScanVC.swift
//  tfm
//
//  Created by Juan Angel Del Rey Sanchez on 20/5/17.
//  Copyright © 2017 Juan Angel Del Rey Sanchez. All rights reserved.
/*
 © Juan Ángel del Rey Sánchez
 Reservados todos los derechos. Está prohibido la reproducción total o parcial de esta obra por cualquier medio o procedimiento, comprendidos la impresión, la reprografía, el microfilme, el tratamiento informático o cualquier otro sistema, así como la distribución de ejemplares mediante alquiler y préstamo, sin la autorización escrita del autor o de los límites que autorice la Ley de Propiedad Intelectual.
 
 */
//

import UIKit
import AVFoundation
import Firebase
import FirebaseAuth
import FirebaseDatabase
import FBSDKLoginKit

class BidiScanVC: UIViewController, AVCaptureMetadataOutputObjectsDelegate {

    
    private var captureSession:AVCaptureSession?
    private var videoPreviewLayer:AVCaptureVideoPreviewLayer?
    private var qrCodeFrameView:UIView?
    private var puntosBIDI:Int = 0
    private var codigoCapturado: Bool = false
    private var indicador: UIActivityIndicatorView = UIActivityIndicatorView()
    
    @IBOutlet weak var lbBidi: UILabel!
    
    let supportedCodeTypes = [AVMetadataObjectTypeUPCECode,
                              AVMetadataObjectTypeCode39Code,
                              AVMetadataObjectTypeCode39Mod43Code,
                              AVMetadataObjectTypeCode93Code,
                              AVMetadataObjectTypeCode128Code,
                              AVMetadataObjectTypeEAN8Code,
                              AVMetadataObjectTypeEAN13Code,
                              AVMetadataObjectTypeAztecCode,
                              AVMetadataObjectTypePDF417Code,
                              AVMetadataObjectTypeQRCode]

    private var ref: FIRDatabaseReference = FIRDatabase.database().reference()    
    private var credential: FIRAuthCredential?
    
    override func viewDidLoad() {
        super.viewDidLoad()
        // Do any additional setup after loading the view, typically from a nib.
        self.indicadorFunc()
        // Get an instance of the AVCaptureDevice class to initialize a device object and provide the video as the media type parameter.
        let captureDevice = AVCaptureDevice.defaultDevice(withMediaType: AVMediaTypeVideo)
        do {
            // Get an instance of the AVCaptureDeviceInput class using the previous device object.
            let input = try AVCaptureDeviceInput(device: captureDevice)
            
            // Initialize the captureSession object.
            captureSession = AVCaptureSession()
            
            // Set the input device on the capture session.
            captureSession?.addInput(input)
            
            // Initialize a AVCaptureMetadataOutput object and set it as the output device to the capture session.
            let captureMetadataOutput = AVCaptureMetadataOutput()
            captureSession?.addOutput(captureMetadataOutput)
            
            // Set delegate and use the default dispatch queue to execute the call back
            captureMetadataOutput.setMetadataObjectsDelegate(self, queue: DispatchQueue.main)
            captureMetadataOutput.metadataObjectTypes = [AVMetadataObjectTypeQRCode]

            // Initialize the video preview layer and add it as a sublayer to the viewPreview view's layer.
            videoPreviewLayer = AVCaptureVideoPreviewLayer(session: captureSession)
            videoPreviewLayer?.videoGravity = AVLayerVideoGravityResizeAspectFill
            videoPreviewLayer?.frame = view.layer.bounds
            view.layer.addSublayer(videoPreviewLayer!)
            
            // Start video capture.
            captureSession?.startRunning()

            // Move the message label and top bar to the front
            view.bringSubview(toFront: lbBidi)
            
            
            // Initialize QR Code Frame to highlight the QR code
            qrCodeFrameView = UIView()
            
            if let qrCodeFrameView = qrCodeFrameView {
                qrCodeFrameView.layer.borderColor = UIColor.green.cgColor
                qrCodeFrameView.layer.borderWidth = 2
                view.addSubview(qrCodeFrameView)
                view.bringSubview(toFront: qrCodeFrameView)
            }
            
        } catch {
            // If any error occurs, simply print it out and don't continue any more.
            print(error)
            return
        }
    }
    
    func captureOutput(_ captureOutput: AVCaptureOutput!, didOutputMetadataObjects metadataObjects: [Any]!, from connection: AVCaptureConnection!) {
        
        //lbBidi.text = "Capturando..."
        
        // Check if the metadataObjects array is not nil and it contains at least one object.
        if metadataObjects == nil || metadataObjects.count == 0 {
            qrCodeFrameView?.frame = CGRect.zero
            lbBidi.text = "No QR code is detected"
            return
        }
        if codigoCapturado {
            //
        }
        else{
            // Get the metadata object.
            let metadataObj = metadataObjects[0] as! AVMetadataMachineReadableCodeObject
            
            if metadataObj.type == AVMetadataObjectTypeQRCode {
                // If the found metadata is equal to the QR code metadata then update the status label's text and set the bounds
                let barCodeObject = videoPreviewLayer?.transformedMetadataObject(for: metadataObj)
                qrCodeFrameView?.frame = barCodeObject!.bounds
                
                if metadataObj.stringValue != nil {
                    self.codigoCapturado = true
                    //------------
                    lbBidi.text = "Puntos Obtenidos:" + metadataObj.stringValue
                    self.puntosBIDI = Int(metadataObj.stringValue)!
                    //delay -> 1sg
                    let delay = 1 // time in seconds
                    Timer.scheduledTimer(timeInterval: TimeInterval(delay), target: self, selector: #selector(savePoint), userInfo: nil, repeats: false)
                    
                }
            }
        }

    }
    
    func changeTab() {
        //switch screen -> go to Profile
        tabBarController?.selectedIndex = 0
    }
    
    func savePoint(){
        //Save points
        
        UIApplication.shared.beginIgnoringInteractionEvents()
        self.indicador.startAnimating()
        //Get credential
        self.credential = FIRFacebookAuthProvider.credential(withAccessToken: FBSDKAccessToken.current().tokenString)
        FIRAuth.auth()?.signIn(with: self.credential!) { (user, error) in
            if let error = error { //failed due to an error
                return
            }
            //Get & update points user
            self.ref.child("users").child((user?.uid)!).observeSingleEvent(of: .value, with: { (snapshot) in
                let value = snapshot.value as? NSDictionary
                //Get puntos from user
                let puntos = value?["points"] as! Int
                print ("--->\(puntos),\(self.puntosBIDI)")
                let resultado = puntos + Int(self.puntosBIDI)
                print ("--->\(resultado)")

                //update user information
                let url = (user?.photoURL!)!
                
                let usuario = [   "name": user?.displayName,
                                  "mail": user?.email,
                                  "uid": user?.uid,
                                  "points": resultado,
                                  "url": "\(url)"] as [String : Any]
                let key = self.ref.child("users").child((user?.uid)!).updateChildValues(usuario)
                
                DispatchQueue.main.async(execute: {
                    UIApplication.shared.endIgnoringInteractionEvents()
                    self.indicador.stopAnimating()
                    self.changeTab()
                })
                
            }){ (error) in print(error.localizedDescription)
                UIApplication.shared.endIgnoringInteractionEvents()
                self.indicador.stopAnimating()
                self.changeTab()
            }
            
            //UIApplication.shared.endIgnoringInteractionEvents()
            //self.indicador.stopAnimating()
            
        }
    }
    override func viewWillAppear(_ animated: Bool) {
        self.codigoCapturado = false
    }
    
    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }
    
    func indicadorFunc(){
        self.indicador.center = self.view.center
        self.indicador.autoresizingMask = [.flexibleBottomMargin, .flexibleLeftMargin, .flexibleWidth, .flexibleRightMargin, .flexibleTopMargin, .flexibleHeight, .flexibleBottomMargin]
        self.indicador.hidesWhenStopped = true
        self.indicador.activityIndicatorViewStyle = .whiteLarge
        self.indicador.color = UIColor.gray
        self.view.addSubview(self.indicador)
    }
    
}
